Attributes JSON REST UI

Attribute | Value
--- | ---

##### Resource ID / URL

##### Method

GET POST PUT DELETE

##### Request Header

#### Request Body

Send x x x x x x x x x x x

#### Result

##### Status Code

##### Response Header

##### Response Body

Clear

### Keyboard Shortcuts

- Ctrl-R - Reload a node
- Ctrl-C - (Re-) Connect to the CSE
- Ctrl-H - Toggle attributes' short / long names display
- Cursor keys and Return key work on the resource tree

### Request Error

Oops! Something went wrong.